# financekit

This is a Python package for financial analysis. The project is in a pre-development release version.
The project is available on [PyPI](https://pypi.org/project/financekit/).

For installation use: 

```
pip install financekit
```

The current version is 0.0.2.